@@ -8,11 +8,12 @@ from .lib import recur_sort
 def load_json() -> Any:
     try:
         json = load(stdin)
-        return recur_sort(json)
     except JSONDecodeError as e:
         print("Error!", e, sep="\n", file=stderr)
         exit(1)
+    else:
+        return recur_sort(json)
 
 
 def dump_json(json: Any, *, indent: int) -> None:
-    dump(json, stdout, ensure_ascii=False, indent=indent)
+    dump(json, stdout, ensure_ascii=False, check_circular=False, indent=indent)
